<?php

namespace App\Http\Controllers;

use App\Models\Action;
use App\Models\Usage;
use Illuminate\Http\Request;

/**
 * Class ActionController
 * @package App\Http\Controllers
 */
class ActionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $actions = Action::paginate();

        return view('action.index', compact('actions'))
            ->with('i', (request()->input('page', 1) - 1) * $actions->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $action = new Action();
        return view('action.create', compact('action'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Action::$rules);

        $action = Action::create($request->all());

        return redirect()->route('provider.index', ['__cx' => time()])
            ->with('success', 'Proveedor creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $action = Action::find($id);

        return view('action.show', compact('action'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = Action::find($id);

        return view('action.edit', compact('action'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Action $provider
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Action $provider)
    {
        request()->validate(Action::$rules);

        $provider->update($request->all());

        return redirect()->route('provider.index', ['__cx' => time()])
            ->with('success', 'Proveedor actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $usagesCount = Usage::query()->where('action_id', $id)->count();

        if($usagesCount > 0) {
            return redirect()->route('provider.index', ['__cx' => time()])
                ->with('error', 'No se puede eliminar el proveedor porque tiene usos asociados en ordenes de retiro');
        }

        $action = Action::find($id)->delete();

        return redirect()->route('provider.index', ['__cx' => time()])
            ->with('success', 'Proveedor eliminado con éxito');
    }
}
