<?php

namespace App\Http\Controllers;

use App\Models\BranchOffice;
use App\Models\Customer;
use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\Product;
use Illuminate\Http\Request;

/**
 * Class BranchOfficeController
 * @package App\Http\Controllers
 */
class BranchOfficeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Customer $customer)
    {
        $branchOffices = BranchOffice::query()
            ->where('customer_id', $customer->id)
            ->paginate(30);

        return view('branch-office.index', compact('branchOffices', 'customer'))
            ->with('i', (request()->input('page', 1) - 1) * $branchOffices->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Customer $customer)
    {
        $branchOffice = new BranchOffice();
        return view('branch-office.create', compact('branchOffice', 'customer'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Customer $customer)
    {
        request()->validate(BranchOffice::$rules);

        $branchOffice = BranchOffice::create($request->all());

        if($request->ajax()){
            return response()->json([
                    'success' => 'Sucursal creada con éxito.',
                ]
            );
        }

        return redirect()->route('branch-offices.index', ['customer' => $customer, '__cx' => time()])
            ->with('success', 'Sucursal creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $branchOffice = BranchOffice::find($id);

        return view('branch-office.show', compact('branchOffice'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Customer $customer, $branch_office)
    {
        $branchOffice = BranchOffice::find($branch_office);

        return view('branch-office.edit', compact('branchOffice', 'customer'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  BranchOffice $branchOffice
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Customer $customer, BranchOffice $branchOffice)
    {
        request()->validate(BranchOffice::$rules);

        $branchOffice->update($request->all());

        if($request->ajax()){
            return response()->json([
                    'success' => 'Sucursal actualizada con éxito.',
                ]
            );
        }

        return redirect()->route('branch-offices.index', ['customer' => $customer,'__cx' => time()])
            ->with('success', 'Sucursal actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy(Customer $customer, $branch_office)
    {
        $branchOffice = BranchOffice::query()->find($branch_office);

        $branchOffice->delete();

        return redirect()->route('branch-offices.index', ['customer' => $customer->id,'__cx' => time()])
            ->with('success', 'Sucursal eliminado con éxito');
    }

    public function loadBranchs(Request $request, Customer $customer)
    {
        $selected = $request->get('selected', null);
        return view('branch-office.show', compact('customer', 'selected'));
    }

    public function loadBranchOffice(Request $request, BranchOffice $branchOffice)
    {
        return response()->json([
                'name' => $branchOffice->name,
                'customer_id' => $branchOffice->customer_id,
                'contact_name' => $branchOffice->contact_name,
                'contact_phone' => $branchOffice->contact_phone,
                'mobile_phone' => $branchOffice->mobile_phone,
                'contact_email'=> $branchOffice->contact_email,
            ]
        );
    }
}
