<?php

namespace App\Http\Controllers;

use App\Models\Brand;
use Illuminate\Http\Request;

/**
 * Class BrandController
 * @package App\Http\Controllers
 */
class BrandController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $brands = Brand::paginate();

        return view('brand.index', compact('brands'))
            ->with('i', (request()->input('page', 1) - 1) * $brands->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $brand = new Brand();
        return view('brand.create', compact('brand'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Brand::$rules);

        $brand = Brand::create($request->all());

        return redirect()->route('brands.index', ['__cx' => time()])
            ->with('success', 'Marca creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $brand = Brand::find($id);

        return view('brand.show', compact('brand'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $brand = Brand::find($id);

        return view('brand.edit', compact('brand'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Brand $brand
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Brand $brand)
    {
        request()->validate(Brand::$rules);

        $brand->update($request->all());

        return redirect()->route('brands.index', ['__cx' => time()])
            ->with('success', 'Marca actualizada con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $brand = Brand::find($id)->delete();

        return redirect()->route('brands.index', ['__cx' => time()])
            ->with('success', 'Marca eliminada con éxito');
    }

    public function buscarMarcas(Request $request)
{
    $search = $request->get('term'); // Captura el término de búsqueda
    $marcas = Brand::where('name', 'LIKE', "%{$search}%")->get();

    return response()->json(
        $marcas->map(function ($marca) {
            return [
                'id' => $marca->id,       // ID de la marca
                'label' => $marca->name, // Nombre para mostrar en el autocompletado
                'value' => $marca->name  // Nombre para completar en el campo de texto
            ];
        })
    );
}

}
