<?php

namespace App\Http\Controllers;

use App\Models\Classe;
use Illuminate\Http\Request;

/**
 * Class ClassController
 * @package App\Http\Controllers
 */
class ClassController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $classes = Classe::paginate();

        return view('class.index', compact('classes'))
            ->with('i', (request()->input('page', 1) - 1) * $classes->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $class = new Classe();
        return view('class.create', compact('class'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Classe::$rules);

        $class = Classe::create($request->all());

        return redirect()->route('classes.index', ['__cx' => time()])
            ->with('success', 'Clase creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $class = Classe::find($id);

        return view('class.show', compact('class'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $class = Classe::find($id);

        return view('class.edit', compact('class'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Class $class
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Classe $classe)
    {
        request()->validate(Classe::$rules);

        $classe->name = $request->name;
        $classe->description = $request->description;
        $classe->save();

        return redirect()->route('classes.index', ['__cx' => time()])
            ->with('success', 'Clase actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $class = Classe::find($id)->delete();

        return redirect()->route('classes.index', ['__cx' => time()])
            ->with('success', 'Clase eliminado con éxito');
    }
}
