<?php

namespace App\Http\Controllers;

use App\Models\BranchOffice;
use App\Models\Customer;
use App\Models\Order;
use Illuminate\Http\Request;

/**
 * Class CustomerController
 * @package App\Http\Controllers
 */
class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $query = Customer::query();

        $search = $request->search ?? '';

        if($search != '') {
            $query->where('name', 'like', '%' . $request->search . '%');
        }

        $customers = $query->paginate(30);

        return view('customer.index', compact('customers', 'search'))
            ->with('i', (request()->input('page', 1) - 1) * $customers->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $customer = new Customer();
        return view('customer.create', compact('customer'));
    }

    public function buscarClientes(Request $request)
{
    $search = $request->get('term');
    $clientes = Customer::where('name', 'LIKE', "%{$search}%")->get();

    $resultado = $clientes->map(function ($cliente) {
        return [
            'id' => $cliente->id,
            'label' => $cliente->name,
            'value' => $cliente->name,
        ];
    });

    return response()->json($resultado);
}

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Customer::$rules);

        $customer = Customer::create($request->all());

        BranchOffice::query()->create([
            'name' => 'Principal',
            'customer_id' => $customer->id,
            'contact_name' => $request->contact_name,
            'contact_phone' => $request->contact_phone,
            'mobile_phone' => $request->mobile_phone,
            'contact_email' => $request->contact_email,
        ]);

        return redirect()->route('customers.index', ['__cx' => time()])
            ->with('success', 'Cliente creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $customer = Customer::find($id);

        return view('customer.show', compact('customer'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $customer = Customer::find($id);
        $coordinates = is_string($customer->coordinates) ? json_decode($customer->coordinates, true) : $customer->coordinates;

        $initialMarkers = [
            [
                'position' => [
                    'lat' => $coordinates['latitude'],
                    'lng' =>  $coordinates['longitude'],
                ],
                'draggable' => true
            ],
        ];

        return view('customer.edit', compact('customer', 'initialMarkers'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Customer $customer
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Customer $customer)
    {
        request()->validate(Customer::$rules);

        $customer->update($request->all());

        return redirect()->route('customers.index', ['__cx' => time()])
            ->with('success', 'Cliente actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $orders = Order::query()->where('customer_id', $id)->count();

        if ($orders > 0) {
            return redirect()->route('customers.index', ['__cx' => time()])
                ->withErrors( ['No se puede eliminar el cliente porque tiene órdenes asociadas']);
        }

        $customer = Customer::find($id)->delete();

        return redirect()->route('customers.index', ['__cx' => time()])
            ->with('success', 'Cliente actualizado con éxito');
    }

    
}
