<?php

namespace App\Http\Controllers;

use App\Actions\PrintcardAction;
use App\Exports\ExportOrders;
use App\Exports\ExportPending;
use App\Exports\ExportRechage;
use App\Exports\ExportTecnico;
use App\Jobs\SendDocumentExternalJob;
use App\Jobs\SendDocumentPrestamoJob;
use App\Models\Action;
use App\Models\Customer;
use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\Prestamo;
use App\Models\Refill;
use App\Models\StockModel;
use App\Models\TypeManagement;
use App\Models\Usage;
use App\Models\User;
use App\Models\Extra;
use Illuminate\Database\Query\Builder;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Maatwebsite\Excel\Excel;
use Auth;
use PhpOffice\PhpWord\IOFactory;
use PhpOffice\PhpWord\Settings;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index(Request $request)
    {
        $extras = Extra::All();
        $statics = [
            'order_today' => Order::query()->whereDate('created_at', now())->whereIn('state', ['WORKSHOP', 'DONE', 'NEW', 'DOING'])->count(),
            'order_7_days' => Order::query()->whereDate('created_at', '<=', now()->subDays(7))->whereIn('state', ['WORKSHOP', 'DOING'])->count(),
            'order_invoiced' => Order::query()->whereIn('state', ['INVOICED'])->count(),
            'order_workshop' => Order::query()->whereIn('state', ['WORKSHOP'])->count(),
        ];

        if(auth()->user()->hasRole('Taller')){
            return $this->roleWorkshop($statics);
        }

        if(auth()->user()->hasRole('Admin')){
            return $this->roleAdmin($statics);
        }

        if(auth()->user()->hasRole('Operaciones')){
            return $this->roleOperaciones($request, $statics);
        }

        if(auth()->user()->hasRole('Planificacion')){
            return $this->rolePlanificacion($request, $statics);
        }
        

        if(auth()->user()->hasRole('Tienda')){
            return $this->roleRecepcion($request, $statics);
        }

        if(auth()->user()->hasRole('Tecnico')){
            return $this->roleTecnico($statics);
        }

        if(auth()->user()->hasRole('Asesor')){
            return $this->roleVendedor($request, $statics);
        }


        return view('home', compact('statics'));
    }

    public function roleVendedor(Request $request, $statics)
    {
        $ordersUser = Order::query()
            ->whereIn('state', ['INVOICED', 'DONE', 'DELIVERED', 'WORKSHOP', 'DOING'])
            ->where('owner_id', auth()->id())
            ->orderBy('id', 'desc')
            ->orderByRaw("CASE
                    WHEN state = 'DONE' THEN 1
                    WHEN state = 'INVOICED' THEN 2
                    WHEN state = 'DELIVERED' THEN 3
                    ELSE 4
                  END")
            ->paginate(30);

        return view('home', compact('statics', 'ordersUser'));
    }

    public function roleTecnico($statics)
    {
        $details = OrderDetail::query()
            //->where('owner_id', auth()->id())
            ->where('state', 'WORKSHOP')
            ->where('state', 'DOING')
            ->paginate(30);
            $extras = Extra::All();
        return view('home', compact('statics', 'details', 'extras'));
    }

    private function roleRecepcion(Request $request, $statics)
    {
        $ordersAll = Order::query()
            ->whereIn('state', ['INVOICED', 'DONE', 'WORKSHOP', 'TO_WORKSHOP', 'DELIVERED'])
            ->Where('owner_id', Auth::user()->id)
            ->orderBy('id', 'desc')
            ->orderByRaw("id DESC, CASE
                    WHEN state = 'TO_WORKSHOP' THEN 1
                    WHEN state = 'DONE' THEN 2
                    WHEN state = 'WORKSHOP' THEN 3
                    ELSE 4
                  END");

        $search = $request->search ?? '';
        $customer = $request->customer ?? '';

        if($search != '') {
            $ordersAll->where('state',  $request->search );
        }

        if($customer != '') {
            $ordersAll->where('customer_id',  $customer );
        }

        $ordersAll =  $ordersAll->paginate(30);

        return view('home', compact('statics', 'ordersAll', 'search', 'customer'));
    }

    private function roleWorkshop($statics)
    {
        $extras = Extra::All();
        $technicals = User::query()
            ->whereHas('roles', function ($query) {
                $query->where('name', 'Tecnico');
            })
            ->get();

        $ordersWorkshop = Order::query()
            ->where('state', 'WORKSHOP')
            ->orWhere('state', 'DOING')
            ->orderBy('id', 'asc')
            ->paginate(30);

        $actions = Action::query()->get();

        return view('home', compact('statics', 'ordersWorkshop', 'technicals', 'extras', 'actions'));
    }

    private function roleOperaciones(Request $request, $statics)
    {
        $ordersAll = Order::query()
            ->whereIn('state', ['INVOICED', 'DONE', 'DOING', 'NEW', 'WORKSHOP', 'TO_WORKSHOP', 'TO_BILLING', 'DELIVERED'])
            ->orderBy('id', 'desc')
            ->orderByRaw("id DESC, CASE
                    WHEN state = 'TO_WORKSHOP' THEN 1
                    WHEN state = 'DONE' THEN 2
                    WHEN state = 'WORKSHOP' THEN 3
                    ELSE 4
                  END");
    
        // Capturar valores de búsqueda
        $search = $request->search ?? '';
        $customer = $request->customer ?? '';
        $orderId = $request->order_id ?? '';
    
        // Filtrar por estado
        if ($search != '') {
            $ordersAll->where('state', $search);
        }
    
        // Filtrar por cliente
        if ($customer != '') {
            $ordersAll->where('customer_id', $customer);
        }
    
        // Filtrar por número de orden
        if ($orderId != '') {
            $ordersAll->where('id', $orderId);
        }
    
        // Continuar con el resto del código
        $ordersByMonth = [];
        $months = ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dic'];
    
        foreach ($months as $key => $month) {
            $ordersByMonth['requested'][$key] = Order::query()->whereIn('state', ['INVOICED', 'NEW', 'WORKSHOP', 'DOING'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['workshop'][$key] = Order::query()->whereIn('state', ['TO_WORKSHOP', 'INVOICED', 'DONE'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['invoiced'][$key] = Order::query()->whereIn('state', ['INVOICED'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
        }
    
        $ordersAll = $ordersAll->paginate(30);
    
        $salesmans = User::query()
            ->whereHas('roles', function ($query) {
                $query->where('name', 'Vendedor');
                $query->orWhere('name', 'Recepcion');
            })
            ->get();
    
        $seriesSales = [];
        $dataSales = [];
    
        foreach ($salesmans as $salesman) {
            $seriesSales[] = $salesman->name;
    
            $ods = Order::query()
                ->where('owner_id', $salesman->id)
                ->whereNotIn('state', ['DRAFT', 'NEW'])
                ->get();
    
            $total = 0;
            foreach ($ods as $od) {
                $total += $od->totalPrice();
            }
    
            $dataSales[] = $total;
        }
    
        return view('home', compact('statics', 'ordersAll', 'seriesSales', 'dataSales', 'search', 'customer', 'ordersByMonth'));
    }

    private function rolePlanificacion(Request $request, $statics)
    {
        $ordersAll = Order::query()
            ->whereIn('state', ['INVOICED', 'DONE', 'DELIVERED'])
            ->orderBy('id', 'desc')
            ->orderByRaw("id DESC, CASE
                    WHEN state = 'INVOICED' THEN 1
                    WHEN state = 'DONE' THEN 2
                    WHEN state = 'DELIVERED' THEN 3
                    ELSE 4
                  END");

        // Capturar valores de búsqueda
        $search = $request->search ?? '';
        $customer = $request->customer ?? '';
        $orderId = $request->order_id ?? '';

        // Filtrar por estado
        if ($search != '') {
            $ordersAll->where('state', $search);
        }

        // Filtrar por cliente
        if ($customer != '') {
            $ordersAll->where('customer_id', $customer);
        }

        // Filtrar por número de orden
        if ($orderId != '') {
            $ordersAll->where('id', $orderId);
        }

        // Continuar con el resto del código
        $ordersByMonth = [];
        $months = ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dic'];

        foreach ($months as $key => $month) {
            $ordersByMonth['requested'][$key] = Order::query()->whereIn('state', ['INVOICED', 'NEW', 'WORKSHOP', 'DOING'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['workshop'][$key] = Order::query()->whereIn('state', ['TO_WORKSHOP', 'INVOICED', 'DONE'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['invoiced'][$key] = Order::query()->whereIn('state', ['INVOICED'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
        }

        $ordersAll = $ordersAll->paginate(30);

        $salesmans = User::query()
            ->whereHas('roles', function ($query) {
                $query->where('name', 'Vendedor');
                $query->orWhere('name', 'Recepcion');
            })
            ->get();

        $seriesSales = [];
        $dataSales = [];

        foreach ($salesmans as $salesman) {
            $seriesSales[] = $salesman->name;

            $ods = Order::query()
                ->where('owner_id', $salesman->id)
                ->whereNotIn('state', ['DRAFT', 'NEW'])
                ->get();

            $total = 0;
            foreach ($ods as $od) {
                $total += $od->totalPrice();
            }

            $dataSales[] = $total;
        }

        $typesManagement = TypeManagement::query()->get();

        return view('home', compact('statics', 'ordersAll', 'seriesSales', 'dataSales', 'search', 'customer', 'ordersByMonth', 'typesManagement'));
    }
    

    public function byPriority()
    {
        $extras = Extra::All();
        $statics = [
            'order_today' => Order::query()->whereDate('created_at', now())->whereIn('state', ['WORKSHOP', 'DONE', 'NEW', 'DOING'])->count(),
            'order_7_days' => Order::query()->whereDate('created_at', '<=', now()->subDays(7))->whereIn('state', ['WORKSHOP', 'DOING'])->count(),
            'order_invoiced' => Order::query()->whereIn('state', ['INVOICED'])->count(),
            'order_workshop' => Order::query()->whereIn('state', ['WORKSHOP'])->count(),
        ];
        $technicals = User::query()
            ->whereHas('roles', function ($query) {
                $query->where('name', 'Tecnico');
            })
            ->get();

        $ordersWorkshop = Order::query()
            ->where('state', 'WORKSHOP')
            ->orWhere('state', 'DOING')
            ->orderBy('priority', 'desc')
            ->paginate(30);

        return view('home', compact('statics', 'ordersWorkshop', 'technicals', 'extras'));
    }

    private function roleAdmin($statics)
    {
        $customers = Customer::query()->orderBy('id', 'desc')->limit(5)->get();

        $ordersByMonth = [];
        $months = ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dic'];

        foreach ($months as $key => $month) {
            $ordersByMonth['requested'][$key] = Order::query()->whereIn('state', ['INVOICED', 'NEW', 'WORKSHOP', 'DOING'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['workshop'][$key] = Order::query()->whereIn('state', ['TO_WORKSHOP', 'INVOICED', 'DONE'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
            $ordersByMonth['invoiced'][$key] = Order::query()->whereIn('state', ['INVOICED'])->whereMonth('created_at', $key + 1)->whereYear('created_at', date('Y'))->count();
        }

        $salesmans = User::query()
            ->whereHas('roles', function ($query) {
                $query->where('name', 'Vendedor');
                $query->orWhere('name', 'Recepcion');
            })
            ->get();

        $seriesSales = [];
        $dataSales = [];

        foreach ($salesmans as $salesman) {

            $seriesSales[] = $salesman->name;

            $ods = Order::query()
                ->where('owner_id', $salesman->id)
                ->whereNotIn('state', ['DRAFT', 'NEW'])
                ->get();

            $total =0;
            foreach ($ods as $od)
            {
                $total += $od->totalPrice();
            }

            $dataSales[] = $total;
        }

        return view('home', compact('statics',  'ordersByMonth', 'seriesSales', 'dataSales', 'customers'));
    }

    public function assign(Request $request) 
    {

        if($request->assign)
        foreach($request->assign as $detailId){
            $detail = OrderDetail::query()->find($detailId);

            $detail->owner_id = $request->get('user');

            $detail->save();
        }

//        if($request->assignOrder)
//            foreach($request->assignOrder as $orderId){
//                $order = Order::query()->find($orderId);
//
//                $order->orderDetails()->update([
//                    'owner_id' => $request->get('user')
//                ]);
//            }

        return redirect()->route('dashboard');
    }

    public function alert()
    {

        $date = Carbon::now();
        $dateOneMonthAgo = $date->addMonth();

        $usages = Usage::query()
            ->where('date_recharge_expiration', '<=', $dateOneMonthAgo)
            ->where('is_recharge', 1)
            ->orderBy('date_recharge_expiration', 'asc')
            ->paginate(30);

        $i = 0;
        $j = 0;

        $refills = Refill::query()->whereRaw('quantity <= (total * 0.1)')->get();

        $usagesApprovers = Usage::query()
            ->whereNull('is_recharge')
            ->whereHas('orderDetail', function ($query) {
               // $query->where('state', 'WORKSHOP');
                $query->whereHas('order', function ($query) {
                    $query->where('id','>',0);
                });
                }
            )  ->orderByRaw("CASE
                    WHEN state = 'NEW' THEN 1
                    WHEN state = 'APPROVED' THEN 2
                    WHEN state = 'REJECTED' THEN 3
                    ELSE 4
                  END")
            ->paginate(20, ['*'], 'approvers');

        $usagesNews = Usage::query()
            //->where('state', 'NEW')
            ->whereNotNull('action_id')
            ->paginate(20, ['*'], 'news');

        $prestamos = Prestamo::query()
            ->whereIn('estado', ['POR APROBAR', 'PRESTADO', 'DEVUELTO', 'RECHAZADO'])
            ->orderBy('id', 'desc')
            ->paginate(30, ['*'], 'prestamos');

        return view('alert.index', compact('usages', 'usagesApprovers', 'refills', 'i', 'j', 'usages', 'usagesNews', 'prestamos'));
    }

    public function alertApproved(Request $request, Usage $usage, $state)
    {
        $usage->state = $state;
        $usage->save();

        return redirect()->back();
    }

    public function alertPrestamoApproved(Request $request, Prestamo $prestamo, $state)
    {

        if($state == 'REJECTED'){
            $estado = 'RECHAZADO';
        }elseif($state == 'DEVUELTO'){
            $estado = 'DEVUELTO';

            foreach($prestamo->prestamoDetail as $detail){

                if($detail->stock_id) {
                    /** @var StockModel $stock */
                    $stock = $detail->stock;

                    $stock->prestados = $stock->prestados - $detail->cantidad;
                    $stock->save();
                }
            }

        }else{
            $estado = 'PRESTADO';

            foreach($prestamo->prestamoDetail as $detail){
                if($detail->stock_id){
                    /** @var StockModel $stock */
                    $stock = $detail->stock;

                    $stock->prestados = $detail->cantidad;
                    $stock->save();
                }
            }

            $templatePath = storage_path('app'. DIRECTORY_SEPARATOR .'formato_prestamo.docx');
            $template = new \PhpOffice\PhpWord\TemplateProcessor($templatePath);
            $template->setImageValue('imagen', [
                'path' => public_path('app'. DIRECTORY_SEPARATOR .'img'. DIRECTORY_SEPARATOR .'logo.png'),
                'width' => 100,
                'height' => 100,
            ]);

            $template->setValue('orden', $prestamo->id);
            $template->setValue('dia', date('d'));
            $template->setValue('mes', date('m'));
            $template->setValue('anio', date('Y'));
            $template->setValue('cliente', $prestamo->customer->name);

            $template->cloneRow('desc', count($prestamo->prestamoDetail));
            $rowIndex = 1;
            foreach ($prestamo->prestamoDetail as $detail)
            {

                if($detail->stock_id){
                    $template->setValue("desc#$rowIndex", $detail->stock->nombre);
                    $template->setValue("brand#$rowIndex", $detail->stock->brand->name);
                    $template->setValue("category#$rowIndex", $detail->stock->categoria);
                    $template->setValue("class#$rowIndex", $detail->stock->clase);
                    $template->setValue("ability#$rowIndex", $detail->stock->capacidad);
                    $template->setValue("serial#$rowIndex", '');

                }else{
                    $template->setValue("desc#$rowIndex", $detail->orderDetail->product->name);
                    $template->setValue("brand#$rowIndex", $detail->orderDetail->product->brand->name);
                    $template->setValue("category#$rowIndex", $detail->orderDetail->product->category->name);
                    $template->setValue("class#$rowIndex", $detail->orderDetail->product->classe->name);
                    $template->setValue("ability#$rowIndex", $detail->orderDetail->product->capacity);
                    $template->setValue("serial#$rowIndex", $detail->orderDetail->serial_number);

                }

                $template->setValue("observation#$rowIndex", '');
                $template->setValue("quantity#$rowIndex", $detail->cantidad);

                $rowIndex++;
            }

            $template->setValue('asesor', $prestamo->owner->name);

            $wordFile = storage_path('app/formato_prestamo_' . $prestamo->id . '.docx');
            $template->saveAs($wordFile);

            Settings::setPdfRendererName(Settings::PDF_RENDERER_TCPDF);
            Settings::setPdfRendererPath(base_path('vendor/tecnickcom/tcpdf'));

            $phpWord = IOFactory::load($wordFile, 'Word2007');

            $pdfFile = storage_path('app/formato_prestamo_' .  $prestamo->id . '.pdf');
            $phpWord->save($pdfFile, 'PDF');
            unlink($wordFile);

            $users = User::role('Operaciones')->get();

            foreach ($users as $user)
            {
                dispatch(new SendDocumentPrestamoJob($user, "Documento Para Prestamos # " . $prestamo->id, $prestamo, $pdfFile));
            }

        }

        $prestamo->estado = $estado;
        $prestamo->save();

        return redirect()->back();
    }

    public function report(Request $request)
    {
        $startDate = $request->input('start_date', date('Y-m-01 00:00:00'));
        $endDate = $request->input('end_date', date('Y-m-d 23:59:59'));

        $orders =  Order::query()->whereBetween('created_at', [$startDate, $endDate])->paginate(30);



        return view('report.index', compact('orders', 'startDate', 'endDate'));
    }

    public function reportExcel(Request $request)
    {
        $startDate = $request->input('start_date', date('Y-m-01 00:00:00'));
        $endDate = $request->input('end_date', date('Y-m-d 23:59:59'));

        $orders =  Order::query()->whereBetween('created_at', [$startDate, $endDate])->get();

        return \Maatwebsite\Excel\Facades\Excel::download(new ExportOrders($orders), 'orders.xlsx');
    }

    public function reportPending(Request $request)
    {
        $ordersDetail = OrderDetail::query()
            ->where('state', 'WORKSHOP')
            ->whereNull('owner_id')
            ->paginate(30);

        return view('report.pending', compact('ordersDetail'));
    }

    public function reportPendingExcel(Request $request)
    {
        $ordersDetail = OrderDetail::query()
            ->where('state', 'WORKSHOP')
            ->whereNull('owner_id')
            ->get();

        return \Maatwebsite\Excel\Facades\Excel::download(new ExportPending($ordersDetail), 'orders_pendings.xlsx');
    }

    public function reportTechnical()
    {
        $technicals = User::query()
            ->whereHas('roles', function ( $query) {
                $query->where('name', 'Tecnico');
            })
            ->get();

        $ordersDetail = OrderDetail::query()
            ->whereIn('state', Order::$statesReportTech)
            ->whereNotNull('owner_id')
            ->paginate(30);

        return view('report.technical', compact('ordersDetail'));
    }

    public function reportTechnicalExcel()
    {
        $ordersDetail = OrderDetail::query()
            ->whereIn('state', Order::$statesReportTech)
            ->whereNotNull('owner_id')
            ->get();

        return \Maatwebsite\Excel\Facades\Excel::download(new ExportTecnico($ordersDetail), 'orders_tecnico.xlsx');
    }

    public function reportRecharge()
    {
        $ordersDetail = OrderDetail::query()
            ->whereIn('state', Order::$statesReportTech)
            ->orderBy('created_at', 'desc')
            ->groupBy('serial_number')
            ->paginate(30);

        return view('report.recharge', compact('ordersDetail'));
    }

    public function reportRechargeExcel()
    {
        $ordersDetail =OrderDetail::query()
            ->whereIn('state', Order::$statesReportTech)
            ->orderBy('created_at', 'desc')
            ->groupBy('serial_number')
            ->get();

        return \Maatwebsite\Excel\Facades\Excel::download(new ExportRechage($ordersDetail), 'orders_recargas.xlsx');
    }

    public function generatePrintCards(Request $request, PrintcardAction $printcardAction)
    {
        foreach ($request->orders as $orderId)
        {
            $printcardAction($orderId);
        }

        return redirect()
            ->back()
            ->with('success', 'Tarjetas creadas con éxito.');
    }

    public function downloadPrintCards(Request $request)
    {
        $doc = file_get_contents(storage_path('app/printCard/detail_'.$request->detail.'.pdf'));

        return response($doc)
            ->header('Content-type', 'application/pdf')
            ->header('Content-Disposition', 'inline; filename="' . 'detail_'.$request->detail.'.pdf' . '"');
        // return response()->downloadS(storage_path('app/printCard/detail_'.$request->detail.'.pdf'));
    }

    public function downloadExternal(Request $request, OrderDetail $orderDetail)
    {
        $doc = file_get_contents(storage_path('app/output/formato_proveedor_'.$orderDetail->id.'.pdf'));

        return response($doc)
            ->header('Content-type', 'application/pdf')
            ->header('Content-Disposition', 'inline; filename="' . 'detail_'.$orderDetail->id.'.pdf' . '"');
        // return response()->downloadS(storage_path('app/printCard/detail_'.$request->detail.'.pdf'));
    }

    public function downloadPrestamo(Request $request, Prestamo $prestamo)
    {
        $doc = file_get_contents(storage_path('app/formato_prestamo_' .  $prestamo->id . '.pdf'));

        return response($doc)
            ->header('Content-type', 'application/pdf')
            ->header('Content-Disposition', 'inline; filename="' . 'prestamo_'.$prestamo->id.'.pdf' . '"');
        // return response()->downloadS(storage_path('app/printCard/detail_'.$request->detail.'.pdf'));
    }

    public function parcial(OrderDetail $orderDetail, $check)
    {
        $orderDetail->parcial = $check;

        $orderDetail->save();

        return ['success' => true, 'message' => 'Entrega parcial actualizado con éxito'];
    }
}
