<?php

namespace App\Http\Controllers;

use App\Models\Management;
use Illuminate\Http\Request;

/**
 * Class ManagementController
 * @package App\Http\Controllers
 */
class ManagementController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $management = Management::paginate();

        return view('management.index', compact('management'))
            ->with('i', (request()->input('page', 1) - 1) * $management->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $management = new Management();
        return view('management.create', compact('management'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Management::$rules);

        $management = Management::create($request->all());

        return redirect()->route('management.index', ['__cx' => time()])
            ->with('success', 'Management creado con éxito.');
    }

    public function storeDashboard(Request $request)
    {
        $management = Management::query()->where('order_id', $request->order)->first() ?? new Management();
        $management->delivery_date = $request->date_delivery;
        $management->order_id = $request->order;
        $management->observation = $request->observations;
        $management->created_by = auth()->id();
        $management->type_management_id = $request->typeManagement;

        $management->save();

        return ['success' => true, 'message' => 'Entrega almacenada con éxito'];
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $management = Management::find($id);

        return view('management.show', compact('management'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $management = Management::find($id);

        return view('management.edit', compact('management'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Management $management
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Management $management)
    {
        request()->validate(Management::$rules);

        $management->update($request->all());

        return redirect()->route('management.index', ['__cx' => time()])
            ->with('success', 'Management actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $management = Management::find($id)->delete();

        return redirect()->route('management.index', ['__cx' => time()])
            ->with('success', 'Management eliminado con éxito');
    }
}
