<?php

namespace App\Http\Controllers;

use App\Jobs\SendOrderToCustomerJob;
use App\Models\BranchOffice;
use App\Models\Brand;
use App\Models\Category;
use App\Models\Classe;
use App\Models\Customer;
use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\PrestamoDetail;
use App\Models\Product;
use App\Models\User;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use SimpleSoftwareIO\QrCode\Facades\QrCode;

/**
 * Class OrderController
 * @package App\Http\Controllers
 */
class OrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $user = $request->user();

        if($user->hasRole('Taller')){
            $orders = Order::query()
                ->where('state', 'TO_WORKSHOP')
                ->orderBy('id', 'desc')->paginate();
        }else{
            $orders = Order::query()
                ->where('owner_id', auth()->id())
                ->whereNot('state', 'DRAFT')
                ->orderBy('id', 'desc')->paginate();
        }
 


        return view('order.index', compact('orders'))
            ->with('i', (request()->input('page', 1) - 1) * $orders->perPage());
    }

    public function updateBulk(Request $request)
{
    // Obtiene los IDs seleccionados
    $orderIds = $request->input('order_ids', []);

    if (!empty($orderIds)) {
        // Actualiza las órdenes seleccionadas
        \App\Models\Order::whereIn('id', $orderIds)->update(['state' => 'TO_BILLING']);
        return redirect()->back()->with('success', 'Las órdenes seleccionadas se han actualizado.');
    }

    // Mensaje de error si no se seleccionaron órdenes
    return redirect()->back()->with('error', 'No se seleccionaron órdenes.');
}

    public function forBilling(Request $request)
    {
        $user = $request->user();

        if($user->hasRole('Operaciones')){
            $orders = Order::query()
                ->where('state', 'DONE')
                ->orwhere('state', 'TO_BILLING')
                ->orderBy('id', 'desc')->paginate();
        }else{
            $orders = Order::query()
                ->where('owner_id', auth()->id())
                ->orderBy('id', 'desc')->paginate();
        }
 


        return view('order.index', compact('orders'))
            ->with('i', (request()->input('page', 1) - 1) * $orders->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $order = Order::query()->create([
            'state' => 'DRAFT',
            'owner_id' => auth()->id(),
        ]);

        return redirect()->route('orders.edit', $order->id);

//        $customers = Customer::query()->pluck('name', 'id');
//
//        $product = new Product();
//
//        $brands = Brand::query()->pluck('name', 'id');
//        $categories = Category::query()->pluck('name', 'id');
//        $classes = Classe::query()->pluck('name', 'id');
//
//        return view('order.create', compact(
//            'order',
//            'product',
//            'customers',
//            'brands',
//            'categories',
//            'classes',
//        ));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Order::$rules);

        $order = Order::create($request->all());

        $order->state = 'NEW';
        $order->save();

        $photoFront = $request->file('photo_front');

        if ($photoFront) {
            $photoFrontName = 'front_' . $order->id .'.'. $photoFront->getClientOriginalExtension();
            $photoFront->move(storage_path('app/orders'), $photoFrontName);
            $order->photo_front = $photoFrontName;
            $order->save();
        }

        $photoBack = $request->file('photo_back');

        if ($photoBack) {
            $photoBackName = 'back_' . $order->id .'.'. $photoFront->getClientOriginalExtension();
            $photoBack->move(storage_path('app/orders'), $photoBackName);
            $order->photo_back = $photoBackName;
            $order->save();
        }

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $order = Order::find($id);

        return view('order.show', compact('order'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $order = Order::query()->find($id);
        $customers = Customer::query()->orderBy('name')->pluck('name', 'id');

        $product = new Product();

        $brands = Brand::query()->orderBy('name', 'asc')->pluck('name', 'id');
        $categories = Category::query()->pluck('name', 'id');
        $classes = Classe::query()->pluck('name', 'id');


        $customer = $order->customer ?? new Customer();
        $branchOffice = new BranchOffice();


        return view('order.create', compact(
            'order',
            'product',
            'customers',
            'brands',
            'categories',
            'classes',
            'customer',
            'branchOffice'
        ));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Order $order
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Order $order)
    {

        if($order->state == 'WORKSHOP'){
            return redirect()->route('orders.index', ['__cx' => time()])
                ->with('success', 'No se puede  actualizar una orden en el taller');
        }

        $order->customer_id = $request->customer_id;
        $order->branch_office_id = $request->branch_office_id;
        $order->state = 'NEW';
        $order->owner_id = auth()->id();
        $order->save();

        $serie = $request->serie;
        $price = $request->price;
        $coordinates = $request->coordinates;
        $observations = $request->observations;


        $listDetail = [];


        foreach ($request->quantity as $detailId =>$quantity)
        {
            $detail = OrderDetail::query()->find($detailId);
           // $technicals = User::query()
           // ->whereHas('roles', function ($query) {
            //    $query->where('name', 'Tecnico');
          //  })
           // ->get();
           // $randomTechnical = $technicals->random();
            $listDetail[] = $detailId;

            $detail->quantity = $quantity;
            $detail->serial_number = $serie[$detailId];
            $detail->price = $price[$detailId];
            $detail->coordinates = $coordinates[$detailId] ? json_decode($coordinates[$detailId]) : null;
            $detail->observation = $observations[$detailId];
           // $detail->owner_id = $randomTechnical->id; // Asignar técnico random

            $detail->save();
        }

        $detailsDelete = OrderDetail::query()->where('order_id', $order->id)
        ->whereNotIn('id', $listDetail)
        ->get();

        if($detailsDelete){
            foreach($detailsDelete as $deleteDetail){
                $deleteDetail->delete();
            }
        }


//        request()->validate(Order::$rules);
//
//        $order->update($request->all());
//
//        $photoFront = $request->file('photo_front');
//
//        if ($photoFront) {
//            $photoFrontName = 'front_' . $order->id .'.'. $photoFront->getClientOriginalExtension();
//            $photoFront->move(storage_path('app/orders'), $photoFrontName);
//            $order->photo_front = $photoFrontName;
//            $order->save();
//        }
//
//        $photoBack = $request->file('photo_back');
//
//        if ($photoBack) {
//            $photoBackName = 'back_' . $order->id .'.'. $photoFront->getClientOriginalExtension();
//            $photoBack->move(storage_path('app/orders'), $photoBackName);
//            $order->photo_back = $photoBackName;
//            $order->save();
//        }

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    public function updatePriority(Request $request)
    {

        $order = Order::find($request->id);
        $order->priority = $request->priority;
        $order->save();

        

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    public function updatePriorityOper(Request $request)
    {

        $order = Order::find($request->id);
        $order->priority = $request->priority;
        $order->save();

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $order = Order::find($id)->delete();

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Order deleted successfully');
    }

    public function photo(Request $request, OrderDetail $order, $s)
    {
        $photo = "photo_{$s}";
        $file = $order->$photo;

        $path = storage_path('app/orders/' . $file);

        if(!file_exists($path) || !$file)
        {
          abort(404);
        }

        $type = pathinfo($path, PATHINFO_EXTENSION);
        $data = file_get_contents($path);

        header("Content-type: image/{$type}");
        echo $data;
    }

    public function toWorkshop(Request $request, Order $order)
    {
        $order->state = 'TO_WORKSHOP';
        $order->date_workshop = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = 'TO_WORKSHOP';
                $detail->save();
            }
        }


        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido enviado a taller con éxito');
    }

    public function workshop(Request $request, Order $order)
    {
        $order->state = 'WORKSHOP';
        $order->date_workshop = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = 'WORKSHOP';
                $detail->save();
            }
        }

//        $pdf = PDF::loadView('order.order', compact('order'));
//
//        $fileOrder = storage_path('app/orders/' . $order->id . '.pdf');
//
//        $pdf->save($fileOrder);
//
//        dispatch(new SendOrderToCustomerJob("Pedido # " . $order->id, $order, $fileOrder));

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido enviado a taller con éxito');
    }

    public function updateExtras(Request $request, $id)
{
    $orderDetail = OrderDetail::findOrFail($id);

    // Convertir las opciones seleccionadas a JSON y guardarlas
    $orderDetail->extras = json_encode($request->input('extras', []));
    $orderDetail->save();

    return redirect()->back()->with('success', 'Extras actualizados correctamente.');
}


    public function doing(Request $request, Order $order)
    {
        $order->state = $request->state;
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = $request->state;
                $detail->save();
            }
        }

//        $pdf = PDF::loadView('order.order', compact('order'));
//
//        $fileOrder = storage_path('app/orders/' . $order->id . '.pdf');
//
//        $pdf->save($fileOrder);
//
//        dispatch(new SendOrderToCustomerJob("Pedido # " . $order->id, $order, $fileOrder));

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido enviado a armando con éxito');
    }


    public function customerEmail(Request $request, Order $order)
    {

        $pdf = PDF::loadView('order.order', compact('order'));

        $fileOrder = storage_path('app/orders/' . $order->id . '.pdf');

        $pdf->save($fileOrder);

        dispatch(new SendOrderToCustomerJob("Pedido # " . $order->id, $order, $fileOrder));

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Documento enviado al cliente con éxito');
    }

    public function photoStore(Request $request, Order $order, OrderDetail $orderDetail)
    {
        $photoFront = $request->file('photo_front');

        if ($photoFront) {
            $photoFrontName = 'front_' . $orderDetail->id .'.'. $photoFront->getClientOriginalExtension();
            $photoFront->move(storage_path('app/orders'), $photoFrontName);
            $orderDetail->photo_front = $photoFrontName;
            $orderDetail->save();
        }

        $photoBack = $request->file('photo_back');

        if ($photoBack) {
            $photoBackName = 'back_' . $orderDetail->id .'.'. $photoFront->getClientOriginalExtension();
            $photoBack->move(storage_path('app/orders'), $photoBackName);
            $orderDetail->photo_back = $photoBackName;
            $orderDetail->save();
        }

        return response()->json([
                'success' => 'Fotos cargadas con éxito.',
                'front' => $photoFrontName ?? '',
                'back' => $photoBackName ?? '',
            ]
        );
    }

    public function tecnical(Request $request, OrderDetail $orderDetail)
    {
        $orderDetail->state = 'DONE';
        $orderDetail->save();

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido finalizado con éxito');
    }

    public function qrCode(OrderDetail $orderDetail)
    {

        if(!file_exists(storage_path('app/qr/' . $orderDetail->id . '.png'))){
            abort(404);
        }

        $qrCode = file_get_contents(storage_path('app/qr/' . $orderDetail->id . '.png'));

        return response($qrCode)->header('Content-type', 'image/png');
    }

    public function invoiced(Request $request, Order $order)
    {
        if($order->state == 'INVOICED'){
            $state = 'DELIVERED';
        }else{
            $state = 'INVOICED';
        }

        if($order->orderDetails)
        {
            $prestamos = 0;
            foreach ($order->orderDetails as $detail)
            {
                $prestamosDetail = PrestamoDetail::query()
                    ->where('order_detail_id', $detail->id)
                    ->where('order_detail_id', $detail->id)
                    ->first();
                if($prestamosDetail && $prestamosDetail?->prestamo?->estado == 'PRESTADO'){
                    $prestamos++;
                }
            }

            if($prestamos > 0){
                return redirect()->route('dashboard', ['__cx' => time()])
                    ->with('error', 'No se puede facturar una orden con prestamos pendientes');
            }
        }

        $order->state = $state;
        $order->start_date = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = $state;
                $detail->save();
            }
        }

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido facturado con éxito');
    }
}
