<?php

namespace App\Http\Controllers;

use App\Jobs\SendOrderToCustomerJob;
use App\Models\BranchOffice;
use App\Models\Brand;
use App\Models\Category;
use App\Models\Classe;
use App\Models\Customer;
use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\Prestamo;
use App\Models\PrestamoDetail;
use App\Models\Product;
use App\Models\StockModel;
use App\Models\User;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use SimpleSoftwareIO\QrCode\Facades\QrCode;

/**
 * Class OrderController
 * @package App\Http\Controllers
 */
class PrestamosOrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $user = $request->user();

        $orders = Prestamo::query()->whereNotNull('estado')->paginate(30);

        $stocks=StockModel::query()->paginate(null, ['*'], 'stocks');


        return view('prestamoOrder.index', compact('orders', 'stocks'))
            ->with('i', (request()->input('page', 1) - 1) * $orders->perPage());
    }

    public function forBilling(Request $request)
    {
        $user = $request->user();

        if($user->hasRole('Operaciones')){
            $orders = Order::query()
                ->where('state', 'DONE')
                ->orwhere('state', 'TO_BILLING')
                ->orderBy('id', 'desc')->paginate();
        }else{
            $orders = Order::query()
                ->where('owner_id', auth()->id())
                ->orderBy('id', 'desc')->paginate();
        }
 


        return view('order.index', compact('orders'))
            ->with('i', (request()->input('page', 1) - 1) * $orders->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $order = Prestamo::query()->create([
            'estado' => 'DRAFT',
            'owner_id' => auth()->id(),
        ]);

        return redirect()->route('prestamos-orders.edit', $order->id);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Order::$rules);

        $order = Order::create($request->all());

        $order->state = 'NEW';
        $order->save();


        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido creado con éxito.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $order = Order::find($id);

        return view('prestamoOrder.show', compact('order'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return mixed
     */
    public function edit($id)
    {
        $order = Prestamo::query()->find($id);
        $prestamo = $order;
        $customers = Customer::query()->orderBy('name')->pluck('name', 'id');

        $product = new Product();

        $brands = Brand::query()->orderBy('name', 'asc')->pluck('name', 'id');
        $categories = Category::query()->pluck('name', 'id');
        $classes = Classe::query()->pluck('name', 'id');
        $capacities = Product::query()
            ->select('capacity')
            ->distinct()
            ->pluck('capacity');


        $customer = $order->customer ?? new Customer();
        $branchOffice = new BranchOffice();

        $categoriesStock = StockModel::query()
            ->select('categoria')
            ->distinct()
            ->pluck('categoria');
        $capacidadStock = StockModel::query()
            ->select('capacidad')
            ->distinct()
            ->pluck('capacidad');


        return view('prestamoOrder.create', compact(
            'order',
            'product',
            'customers',
            'brands',
            'categories',
            'classes',
            'customer',
            'branchOffice',
            'prestamo',
            'categoriesStock',
            'capacidadStock',
            'capacities',
        ));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Order $order
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Prestamo $prestamosOrder)
    {

        if($prestamosOrder->state == 'WORKSHOP'){
            return redirect()->route('orders.index', ['__cx' => time()])
                ->with('success', 'No se puede  actualizar una orden en el taller');
        }

        $prestamosOrder->customer_id = $request->customer_id;
        $prestamosOrder->branch_office_id = $request->branch_office_id;
        $prestamosOrder->estado = 'POR APROBAR';
        $prestamosOrder->owner_id = auth()->id();
        $prestamosOrder->fecha_prestado = $request->fecha_prestado;
        $prestamosOrder->fecha_devolucion = $request->fecha_devolucion;
        $prestamosOrder->save();

        $listDetail = [];


        foreach ($request->quantity as $detailId =>$quantity)
        {
            $detail = PrestamoDetail::query()->find($detailId);

            $listDetail[] = $detailId;

            $detail->cantidad = $quantity;

            $detail->save();
        }

        $detailsDelete = PrestamoDetail::query()->where('prestamo_id', $prestamosOrder->id)
        ->whereNotIn('id', $listDetail)
        ->get();

        if($detailsDelete){
            foreach($detailsDelete as $deleteDetail){
                $deleteDetail->delete();
            }
        }


        return redirect()->route('prestamos-orders.index', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    public function updatePriority(Request $request)
    {

        $order = Order::find($request->id);
        $order->priority = $request->priority;
        $order->save();

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    public function updatePriorityOper(Request $request)
    {
        $order = Order::find($request->id);
        $order->priority = $request->priority;
        $order->save();

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $order = Order::find($id)->delete();

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Order deleted successfully');
    }

    public function photo(Request $request, OrderDetail $order, $s)
    {
        $photo = "photo_{$s}";
        $file = $order->$photo;

        $path = storage_path('app/orders/' . $file);

        if(!file_exists($path) || !$file)
        {
          abort(404);
        }

        $type = pathinfo($path, PATHINFO_EXTENSION);
        $data = file_get_contents($path);

        header("Content-type: image/{$type}");
        echo $data;
    }

    public function toWorkshop(Request $request, Order $order)
    {
        $order->state = 'TO_WORKSHOP';
        $order->date_workshop = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = 'TO_WORKSHOP';
                $detail->save();
            }
        }


        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido enviado a taller con éxito');
    }

    public function workshop(Request $request, Order $order)
    {
        $order->state = 'WORKSHOP';
        $order->date_workshop = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = 'WORKSHOP';
                $detail->save();
            }
        }

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Pedido enviado a taller con éxito');
    }

    public function updateExtras(Request $request, $id)
{
    $orderDetail = OrderDetail::findOrFail($id);

    // Convertir las opciones seleccionadas a JSON y guardarlas
    $orderDetail->extras = json_encode($request->input('extras', []));
    $orderDetail->save();

    return redirect()->back()->with('success', 'Extras actualizados correctamente.');
}


    public function doing(Request $request, Order $order)
    {
        $order->state = $request->state;
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = $request->state;
                $detail->save();
            }
        }

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido enviado a armando con éxito');
    }


    public function customerEmail(Request $request, Order $order)
    {

        $pdf = PDF::loadView('order.order', compact('order'));

        $fileOrder = storage_path('app/orders/' . $order->id . '.pdf');

        $pdf->save($fileOrder);

        dispatch(new SendOrderToCustomerJob("Pedido # " . $order->id, $order, $fileOrder));

        return redirect()->route('orders.index', ['__cx' => time()])
            ->with('success', 'Documento enviado al cliente con éxito');
    }

    public function photoStore(Request $request, Order $order, OrderDetail $orderDetail)
    {
        $photoFront = $request->file('photo_front');

        if ($photoFront) {
            $photoFrontName = 'front_' . $orderDetail->id .'.'. $photoFront->getClientOriginalExtension();
            $photoFront->move(storage_path('app/orders'), $photoFrontName);
            $orderDetail->photo_front = $photoFrontName;
            $orderDetail->save();
        }

        $photoBack = $request->file('photo_back');

        if ($photoBack) {
            $photoBackName = 'back_' . $orderDetail->id .'.'. $photoFront->getClientOriginalExtension();
            $photoBack->move(storage_path('app/orders'), $photoBackName);
            $orderDetail->photo_back = $photoBackName;
            $orderDetail->save();
        }

        return response()->json([
                'success' => 'Fotos cargadas con éxito.',
                'front' => $photoFrontName ?? '',
                'back' => $photoBackName ?? '',
            ]
        );
    }

    public function tecnical(Request $request, OrderDetail $orderDetail)
    {
        $orderDetail->state = 'DONE';
        $orderDetail->save();

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido finalizado con éxito');
    }

    public function qrCode(OrderDetail $orderDetail)
    {

        if(!file_exists(storage_path('app/qr/' . $orderDetail->id . '.png'))){
            abort(404);
        }

        $qrCode = file_get_contents(storage_path('app/qr/' . $orderDetail->id . '.png'));

        return response($qrCode)->header('Content-type', 'image/png');
    }

    public function invoiced(Request $request, Order $order)
    {
        if($order->state == 'INVOICED'){
            $state = 'DELIVERED';
        }else{
            $state = 'INVOICED';
        }

        $order->state = $state;
        $order->start_date = now();
        $order->save();

        if($order->orderDetails)
        {
            foreach ($order->orderDetails as $detail)
            {
                $detail->state = $state;
                $detail->save();
            }
        }

        return redirect()->route('dashboard', ['__cx' => time()])
            ->with('success', 'Pedido facturado con éxito');
    }

    public function searchStock(Request $request)
    {
        $productQuery = StockModel::query()->select('stock_models.*')
            ->join('brands', 'brands.id', '=', 'stock_models.brand_id')
            ->orderBy('brands.name');

        if($request->has('capacidad') && $request->capacidad){
            $productQuery->where('capacidad', $request->capacidad);
        }

        if($request->has('categoria') && $request->categoria){
            $productQuery->where('categoria', $request->categoria);
        }

        return view('prestamoOrder.search', ['products' => $productQuery->get(), 'i' => 0]);
    }

    public function addPrestamoDetail(Request $request)
    {
        $order = Prestamo::query()->find($request->order);
        $product = StockModel::query()->find($request->product);
        $orderDetail = PrestamoDetail::query()->create([
            'prestamo_id' => $order->id,
            'stock_id' => $product->id,
        ]);

        return response()->json([
                'success' => 'Producto creado con éxito.',
                'detail' => $orderDetail->id,
                'data' => [
                    'prestamo' => $order,
                    'prestamo_detail' => $orderDetail,
                    'stock' => $product,
                ],
                'html' => view('prestamoOrder.row', compact('product', 'orderDetail', 'order'))->render(),
            ]
        );
    }

    public function addPrestamoDetailOrder(Request $request)
    {
        $order = Prestamo::query()->find($request->order);
        $orderDetail = OrderDetail::query()->find($request->orderDetail);
        $prestamoOrderDetail = PrestamoDetail::query()->create([
            'prestamo_id' => $order->id,
            'order_detail_id' => $orderDetail->id,
        ]);

        return response()->json([
                'success' => 'Producto creado con éxito.',
                'detail' => $prestamoOrderDetail->id,
                'data' => [
                    'prestamo' => $order,
                    'prestamo_detail' => $prestamoOrderDetail,
                    'orderDetail' => $orderDetail,
                ],
                'html' => view('prestamoOrder.rowOrder', compact('orderDetail', 'prestamoOrderDetail', 'order'))->render(),
            ]
        );
    }

    public function searchOrderPrestamo(Request $request)
    {
        //$orders = Order::query()->where('state', 'DONE')->get();

        $productQuery = OrderDetail::query()->select('order_details.*')

            ->join('products', function ($join) {
                $join->on('order_details.product_id', '=', 'products.id')
                    ->where('order_details.state', 'DONE')
                    ->whereNotIn('order_details.id', PrestamoDetail::query()->whereHas('prestamo', function ($query) {
                        $query->where('estado', 'PRESTADO');
                    })->pluck('id') );
            })
            ->join('brands', 'brands.id', '=', 'products.brand_id')
            ->orderBy('brands.name')
        ->with('product')
        ->with('product.brand')
        ;

        if ($request->has('categoria') && $request->categoria) {
            $productQuery->where('products.category_id', $request->categoria);
        }

        if ($request->has('capacidad') && $request->capacidad) {
            $productQuery->where('products.capacity', $request->capacidad);
        }



        return view('prestamoOrder.searchOrder', ['orderDetails' => $productQuery->get(), 'i' => 0]);
    }

}
