<?php

namespace App\Http\Controllers;

use App\Models\TypeManagement;
use Illuminate\Http\Request;

/**
 * Class TypeManagementController
 * @package App\Http\Controllers
 */
class TypeManagementController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $typeManagements = TypeManagement::paginate();

        return view('type-management.index', compact('typeManagements'))
            ->with('i', (request()->input('page', 1) - 1) * $typeManagements->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $typeManagement = new TypeManagement();
        return view('type-management.create', compact('typeManagement'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(TypeManagement::$rules);

        $typeManagement = TypeManagement::create($request->all());

        return redirect()->route('type-managements.index', ['__cx' => time()])
            ->with('success', 'Tipo Gestión creado con éxito');
    }



    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $typeManagement = TypeManagement::find($id);

        return view('type-management.show', compact('typeManagement'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typeManagement = TypeManagement::find($id);

        return view('type-management.edit', compact('typeManagement'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  TypeManagement $typeManagement
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, TypeManagement $typeManagement)
    {
        request()->validate(TypeManagement::$rules);

        $typeManagement->update($request->all());

        return redirect()->route('type-managements.index', ['__cx' => time()])
            ->with('success', 'Tipo de Gestión actualizado con éxito');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $typeManagement = TypeManagement::find($id)->delete();

        return redirect()->route('type-managements.index', ['__cx' => time()])
            ->with('success', 'Tipo de Gestión eliminado con éxito');
    }
}
