<?php

namespace App\Jobs;

use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Mail\Mailer;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Symfony\Component\Mime\Email;

class SendDocumentExternalJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(protected User $user, protected $subject = null, protected OrderDetail $order, protected $attach = null)
    {
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle(Mailer $mailer)
    {
        $subject = $this->subject;
        $attach = $this->attach;
        $order = $this->order;

        $this->sendEmail($mailer, $this->user->email, $this->user->name, $subject, $attach, $order);
    }

    private function sendEmail(Mailer $mailer, $email, $name, $subject, $attach, $order){
        $mailer->send('emails.external', compact('order'), function ($m) use($subject, $order, $attach, $email, $name) {
            $m->subject($subject);

            $m->to(
                $email,
                $name
            );

            if($attach){
                $m->attach($attach, ['as' => 'order_proveedor_'. $order->id .'.pdf', 'mime' => 'application/pdf']);
            }
        });
    }
}
