<?php

namespace App\Jobs;

use App\Models\Order;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Mail\Mailer;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Symfony\Component\Mime\Email;

class SendOrderToCustomerJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(protected $subject = null, protected Order $order, protected $attach = null)
    {
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle(Mailer $mailer)
    {
        $subject = $this->subject;
        $attach = $this->attach;
        $order = $this->order;


        $this->sendEmail($mailer, $order->customer->email, $order->customer->name, $subject, $attach, $order);
        $this->sendEmail($mailer, $order->owner->email, $order->owner->email, $subject, $attach, $order);

        if($order->customer->contact_email) {
            $this->sendEmail($mailer, $order->customer->contact_email, $order->customer->contact_name, $subject, $attach, $order);
        }
    }

    private function sendEmail(Mailer $mailer, $email, $name, $subject, $attach, $order){
        $mailer->send('emails.order', compact('order'), function ($m) use($subject, $order, $attach, $email, $name) {
            $m->subject($subject);

            $m->to(
                $email,
                $name
            );

            if($attach){
                $m->attach($attach, ['as' => 'pedido_'. $order->id .'.pdf', 'mime' => 'application/pdf']);
            }
        });
    }
}
