<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Carbon;
use OwenIt\Auditing\Contracts\Auditable;

/**
 * Class Order
 *
 * @property $id
 * @property $product_id
 * @property $serial_number
 * @property $observation
 * @property $price
 * @property $created_at
 * @property $updated_at
 *
 * @property Product $product
 * @package App
 * @mixin \Illuminate\Database\Eloquent\Builder
 */
class Order extends Model implements Auditable
{

    use \OwenIt\Auditing\Auditable;
    use SoftDeletes;

    static $rules = [
    ];

    protected $fillable = [
        'state',
        'priority',
        'owner_id',
    ];

    protected $casts = [
        'date_workshop' => 'datetime',
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
    ];

    protected $perPage = 20;


    public function owner()
    {
        return $this->hasOne('App\Models\User', 'id', 'owner_id');
    }

    public function customer()
    {
        return $this->hasOne('App\Models\Customer', 'id', 'customer_id');
    }

    public function orderDetails()
    {
        return $this->hasMany('App\Models\OrderDetail', 'order_id', 'id');
    }

    public function brancOffice()
    {
        return $this->hasOne('App\Models\BranchOffice', 'id', 'branch_office_id');
    }

    public static $states = [
            'DRAFT' => 'Borrador',
            'NEW' => 'Nuevo',
            'TO_WORKSHOP' => 'Para Area Tecnica',
            'WORKSHOP' => 'En Area Tecnica',
            'DOING' => 'Armando',
            'DONE' => 'Terminado',
            'TO_BILLING' => 'Enviado para facturación',
            'INVOICED' => 'Facturado',
            'DELIVERED' => 'Entregado',
        ];

    public static $statesDash = [
        'TO_WORKSHOP' => 'Para Area Tecnica',
        'WORKSHOP' => 'En Area Tecnica',
        'DOING' => 'Armando',
        'DONE' => 'Terminado',
        'TO_BILLING' => 'Enviado para facturación',
        'INVOICED' => 'Facturado',
        'DELIVERED' => 'Entregado',
    ];

    public static $statesReportTech = [

        'DONE',
        'INVOICED',
        'DELIVERED',
    ];

    public function totalPrice()
    {
        $totalPrice = 0;

        foreach ($this->orderDetails as $orderDetail) {
            $totalPrice += $orderDetail->total();
        }

        return $totalPrice;
    }

    public function totalQuantity()
    {
        $total = 0;

        foreach ($this->orderDetails as $orderDetail) {
            $total += $orderDetail->quantity;
        }

        return $total;
    }

    public function getCreatedAtFormatAttribute($value){
        return $this->created_at->format('d-m-Y H:i:s');
    }

    public function getUpdatedAtFormatAttribute($value){
        return $this->updated_at->format('d-m-Y H:i:s');
    }

    public function total()
    {
        $total = 0;

        foreach ($this->orderDetails as $orderDetail) {
            $total += $orderDetail->total();
        }

        return $total;
    }

    public function canFinish()
    {
        $canFinish = true;

        foreach ($this->orderDetails as $orderDetail) {
            $canFinish = $canFinish && $orderDetail->canFinnish();
        }

        return $canFinish;
    }
}
