<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use OwenIt\Auditing\Contracts\Auditable;

class OrderDetail extends Model implements Auditable
{
    use HasFactory;
    use \OwenIt\Auditing\Auditable;

    protected $fillable = [
        'id',
        'order_id',
        'product_id',
        'quantity',
        'quantity_prestado',
        'extras',
        'price',
        'total',
        'observation',
    ];

    protected $casts = [
        'coordinates' => 'array',
    ];

    public function product()
    {
        return $this->hasOne('App\Models\Product', 'id', 'product_id');
    }

    public function owner()
    {
        return $this->hasOne('App\Models\User', 'id', 'owner_id');
    }

    public function order()
    {
        return $this->hasOne('App\Models\Order', 'id', 'order_id');
    }

    public function usages()
    {
        return $this->hasMany('App\Models\Usage', 'order_detail_id', 'id');
    }

    public function canFinnish()
    {
        $total = $this->usages()->count();
        $approves = $this->usages()->whereIn('state', ['APPROVED', 'REJECTED'])->count();
        return $total > 0 && $total == $approves;
    }

    public function usageDateRecharge()
    {

        return $this->usages()
            ->where('is_recharge', true)
            ->first()
            ?->date_recharge_expiration;
    }

    public function usageRecharge()
    {

        return $this->usages()
            ->where('is_recharge', true)
            ->first();
    }

      public function total(){
        $price = $this->price;

        $usages = $this->usages()->whereNull('is_recharge')
            ->where('state', 'APPROVED')
            ->get();

        if(!$usages){
            return $price;
        }


            foreach ($usages as $usage){
                $price += $usage->quantity * $usage->refill->price_unit;
            }


        return $price;
    }

    public function prestamoOrderDetail()
    {
        return $this->hasOne('App\Models\PrestamoDetail', 'order_detail_id', 'id');
    }

    public function prestados()
    {
        return $this->prestamoOrderDetail()
            ->whereHas('prestamo',  function ($query) {
                $query->where('estado', 'PRESTADO');
            })
        ->count();
    }
}
