<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use OwenIt\Auditing\Auditable;

/**
 * Class Product
 *
 * @property $id
 * @property $name
 * @property $brand_id
 * @property $category_id
 * @property $class_id
 * @property $description
 * @property $capacity
 * @property $rating
 * @property $approval
 * @property $range
 * @property $temp_range
 * @property $discharge_time
 * @property $psi
 * @property $height
 * @property $width
 * @property $diameter
 * @property $weight
 * @property $created_at
 * @property $updated_at
 * @property $deleted_at
 *
 * @property Brand $brand
 * @property Category $category
 * @property Class $class
 * @package App
 * @mixin \Illuminate\Database\Eloquent\Builder
 */
class Product extends Model implements \OwenIt\Auditing\Contracts\Auditable
{
    use SoftDeletes;
    use Auditable;

    static $rules = [
		'name' => 'required',
    ];

    protected $perPage = 20;

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = ['name','brand_id','category_id','class_id','description','capacity','rating','approval','range','temp_range','discharge_time','psi','height','width','diameter','weight'];


    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function brand()
    {
        return $this->hasOne('App\Models\Brand', 'id', 'brand_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function category()
    {
        return $this->hasOne('App\Models\Category', 'id', 'category_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function classe()
    {
        return $this->hasOne('App\Models\Classe', 'id', 'class_id');
    }

    public function orderDetail()
    {
        return $this->hasMany('App\Models\OrderDetail', 'product_id', 'id');
    }


}
