<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use OwenIt\Auditing\Contracts\Auditable;

/**
 * Class Refill
 *
 * @property $id
 * @property $name
 * @property $brand_id
 * @property $code
 * @property $price
 * @property $price_unit
 * @property $quantity
 * @property $invoice
 * @property $deliver_date
 * @property $created_at
 * @property $updated_at
 * @property $deleted_at
 *
 * @property Brand $brand
 * @package App
 * @mixin \Illuminate\Database\Eloquent\Builder
 */
class Refill extends Model implements Auditable
{
    use SoftDeletes;
    use \OwenIt\Auditing\Auditable;

    static $rules = [
		'name' => 'required',
		'price' => 'required|numeric',
		'price_unit' => 'required|numeric',
    ];

    protected $perPage = 20;

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = ['name','brand_id','code','price','price_unit','invoice','deliver_date', 'total'];


    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function brand()
    {
        return $this->hasOne('App\Models\Brand', 'id', 'brand_id');
    }


}
