@extends('layouts.main')

@section('title', '| Alertas')
@section('titlePage', 'Alertas')

@section('content')
    @role('Admin|Vendedor|Recepcion|Operaciones')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Alertas de Recarga') }}</h2>
            </div>
        </div>
        @if ($message = Session::get('success'))
            <div class="alert alert-success">
                <p>{{ $message }}</p>
            </div>
        @endif

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                        <tr>
                            <th>Cliente</th>

										<th>Tel&eacute;fono</th>
										<th>Extintor</th>
										<th>Descripci&oacute;n</th>
										<th>Vencimiento</th>
										<th>Restantes</th>
										<th>Alerta</th>

                            <th></th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($usages as $usage)
                            <tr>
                                <td>{{ $usage->orderDetail?->order?->customer?->name }}</td>
                                <td>{{ $usage->orderDetail?->order?->customer?->phones }}</td>
                                <td>{{ $usage->orderDetail?->product?->name }}</td>
                                <td>{{ $usage->orderDetail?->product?->description }}</td>
                                <td>{{ $usage->date_recharge_expiration }}</td>
                                <td>{{ now()->diffForHumans($usage->date_recharge_expiration) }}</td>
                                <td>
                                    <p class="alert alert-warning">Quedan pocos días de vigencia</p>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
                {{$usages->links('pagination::bootstrap-5')}}
            </div>
        </div>
    </div>
    @endrole

    @role('Admin|Recepcion|Operaciones')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Alertas de Stock') }}</h2>
            </div>
        </div>
        @if ($message = Session::get('success'))
            <div class="alert alert-success">
                <p>{{ $message }}</p>
            </div>
        @endif

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                    <tr>
                        <th>No</th>

                        <th>Producto</th>
                        <th>Stock</th>

                        <th></th>
                    </tr>
                    </thead>
                    <tbody>
                        @foreach($refills as $refill)
                            <tr>
                                <td>{{ ++$i }}</td>
                                <td>{{ $refill->name }}</td>
                                <td>{{ $refill->quantity }} Unidades</td>
                                <td>
                                    <p class="alert alert-warning">Quedan pocos unidades</p>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>

            </div>
        </div>
    </div>
    @endrole

    @role('Vendedor|Recepcion|Taller|Operaciones')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Alertas de Aprobación') }}</h2>
            </div>
        </div>

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                    <tr>
                        <th>No</th>

                        <th>Orden</th>
                        <th>Cliente</th>
                        <th>Sucursal</th>
                        <th>Telefono</th>
                        <th>Producto</th>
                        <th>Cantidad</th>
                        <th>Precio</th>
                        <th>Técnico</th>

                        <th></th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($usagesApprovers as $usage)
                        <tr>
                            <td>{{ ++$j }}</td>
                            <td>{{$usage?->orderDetail?->order->id}}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->brancOffice?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->phones }}</td>
                            <td>{{$usage?->refill?->name}}</td>
                            <td>{{$usage?->quantity}}</td>
                            <td>{{$usage?->refill?->price_unit}}</td>
                            <td>{{$usage?->orderDetail?->owner?->name}}</td>
                            <td>
                                @if($usage?->state == 'NEW')
                                <a class="btn btn-primary"
                                   onclick="return confirm('¿Está seguro de aprobar el repuesto?')"
                                   href="{{ route('alert.aprroved', [$usage, 'APPROVED']) }}">Aprobar</a>
                                <a class="btn btn-danger"
                                   onclick="return confirm('¿Está seguro de rechazar el repuesto?')"
                                   href="{{ route('alert.aprroved', [$usage, 'REJECTED']) }}">Rechazar</a>
                                @else
                                    <p class="alert alert-success">{{$usage?->state}}</p>
                                @endif
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {{$usagesApprovers->links('pagination::bootstrap-5')}}
            </div>
        </div>
    </div>
    @endrole

    @role('Operaciones')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Aprobaciones externos') }}</h2>
            </div>
        </div>

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                    <tr>
                        <th>No</th>

                        <th>Orden</th>
                        <th>Cliente</th>
                        <th>Sucursal</th>
                        <th>Telefono</th>
                        <th>Acci&oacute;n</th>
                        <th>Proveedor</th>

                        <th></th>
                        <th></th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($usagesNews as $usage)
                        <tr>
                            <td>{{ ++$j }}</td>
                            <td>{{$usage?->orderDetail?->order->id}}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->brancOffice?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->phones }}</td>

                            <td>{{ $usage->action?->action }}</td>
                            <td>
                                {{ $usage->action?->provider }}<br>
                                {{ $usage->action?->contact }}<br>
                                {{ $usage->action?->phone }}<br>
                                {{ $usage->action?->email }}
                            </td>
                            <td>
                                <a target="__blank" href="{{route('download.external', $usage->orderDetail)}}"><i class="la la-download"></i></a>
                            </td>
                            <td>
                                @if($usage?->state == 'NEW')
                                    <a class="btn btn-primary"
                                       onclick="return confirm('¿Está seguro de recibir este extintor?')"
                                       href="{{ route('alert.aprroved', [$usage, 'APPROVED']) }}">Recibir</a>
{{--                                    <a class="btn btn-danger"--}}
{{--                                       onclick="return confirm('¿Está seguro de rechazar el repuesto?')"--}}
{{--                                       href="{{ route('alert.aprroved', [$usage, 'REJECTED']) }}">Rechazar</a>--}}
                                @else
                                    <p class="alert alert-success">Recibido</p>
                                @endif
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {{$usagesApprovers->links('pagination::bootstrap-5')}}
            </div>
        </div>
    </div>
    @endrole

    @role('Taller')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Aprobaciones externos') }}</h2>
            </div>
        </div>

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                    <tr>
                        <th>No</th>

                        <th>Orden</th>
                        <th>Cliente</th>
                        <th>Sucursal</th>
                        <th>Telefono</th>
                        <th>Acci&oacute;n</th>
                        <th>Proveedor</th>


                        <th></th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($usagesNews as $usage)
                        <tr>
                            <td>{{ ++$j }}</td>
                            <td>{{$usage?->orderDetail?->order->id}}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->brancOffice?->name }}</td>
                            <td>{{ $usage->orderDetail?->order?->customer?->phones }}</td>

                            <td>{{ $usage->action?->action }}</td>
                            <td>
                                {{ $usage->action?->provider }}<br>
                                {{ $usage->action?->contact }}<br>
                                {{ $usage->action?->phone }}<br>
                                {{ $usage->action?->email }}
                            </td>

                            <td>
                                @if($usage?->state == 'NEW')
                                    Pendiente de recibir
                                @else
                                    <p class="alert alert-success">Recibido</p>
                                @endif
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {{$usagesApprovers->links('pagination::bootstrap-5')}}
            </div>
        </div>
    </div>
    @endrole

{{--     Pretamos--}}
    @role('Operaciones|Vendedor|Recepcion|Asesor|Tienda')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Prestamos') }}</h2>
            </div>
        </div>

        <div class="card-body">
            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                    <tr>
                        <th>Cliente</th>
                        <th>Fecha de préstamos</th>
                        <th>Fecha de devolucion</th>
                        <th>Cantidad</th>

                        <th></th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($prestamos as $prestamo)
                        <tr>
                            <td>{{$prestamo->customer->name}}</td>
                            <td>{{$prestamo->fecha_prestado?->format('d-m-Y')}}</td>
                            <td>{{$prestamo->fecha_devolucion?->format('d-m-Y')}}</td>
                            <td>
                                <a href="#" data-bs-toggle="modal" data-bs-target="#lst-{{$prestamo->id}}">
                                    {{$prestamo->prestamoDetail()->count()}}
                                </a>

                                <div class="modal fade"  id="lst-{{$prestamo->id}}">
                                    <div class="modal-dialog modal-dialog-centered text-center modal-xl" role="document">
                                        <div class="modal-content modal-content-demo">
                                            <div class="modal-header">
                                                <h6 class="modal-title">Lista de extintores</h6><button aria-label="Close" class="btn-close" data-bs-dismiss="modal">x</button>
                                            </div>

                                            <div class="table-responsive">
                                                <table class="table mg-b-0 text-md-nowrap" id="tblOrder">
                                                    <thead>
                                                    <tr>
                                                        <th></th>
                                                        <th>Cantidad</th>
                                                        <th>Categoría del equipo</th>
                                                        <th>Nombre</th>
                                                        <th>Marca</th>
                                                        <th>Clase</th>
                                                        <th>Capacidad</th>
                                                        <th></th>
                                                    </tr>
                                                    </thead>
                                                    <tbody>
                                                    @foreach($prestamo->prestamoDetail as $detail)
                                                        @include('prestamoOrder.rowAlert', ['product' => $detail->stock, 'order' => $prestamo, 'orderDetail' => $detail])
                                                    @endforeach
                                                    </tbody>
                                                </table>
                                            </div>

                                        </div>
                                    </div>
                                </div>

                            </td>

                            <td>
                                @if(file_exists(storage_path('app/formato_prestamo_' .  $prestamo->id . '.pdf')))
                                    <a href="{{route('download.prestamo', $prestamo)}}" target="_blank"><i class="la la-download"></i> Documento</a>
                                @endif
                                @role('Operaciones')
                                @if($prestamo->estado == 'POR APROBAR')
                                    <a class="btn btn-primary"
                                       onclick="return confirm('¿Está seguro de aprobar el prestamo?')"
                                       href="{{ route('alert-prestamo.aprroved', [$prestamo, 'APPROVED']) }}">Aprobar</a>
                                    <a class="btn btn-danger"
                                       onclick="return confirm('¿Está seguro de rechazar el prestamo?')"
                                       href="{{ route('alert-prestamo.aprroved', [$prestamo, 'REJECTED']) }}">Rechazar</a>
                                @elseif($prestamo->estado == 'RECHAZADO')
                                    <p class="alert alert-danger">{{$prestamo?->estado}}</p>
                                @elseif($prestamo->estado == 'PRESTADO')
                                    <p class="alert alert-warning">{{$prestamo?->estado}}</p>

                                    <a class="btn btn-primary"
                                       onclick="return confirm('¿Está seguro que queire marcar como devuelto el prestamo?')"
                                       href="{{ route('alert-prestamo.aprroved', [$prestamo, 'DEVUELTO']) }}">Devolver</a>
                                @else
                                    <p class="alert alert-success">{{$prestamo?->estado}}</p>
                                @endif
                                @endrole

                                @role('Vendedor|Recepcion|Asesor|Tienda')
                                    <p class="alert alert-success">{{$prestamo?->estado}}</p>
                                @endrole
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {!! $prestamos->links('pagination::bootstrap-5') !!}
            </div>
        </div>
    </div>
    @endrole
@endsection
