@extends('layouts.main')

@section('title', '| Clientes')
@section('titlePage', 'Clientes')

@section('page-styles')
    @mapstyles

    <style>
        .gnw-map-service {
            height: 200px;
            width: 200px;
        }

    </style>
@endsection

@section('content')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Listado de clientes') }}</h2>
            </div>
        </div>
        @if ($message = Session::get('success'))
            <div class="alert alert-success">
                <p>{{ $message }}</p>
            </div>
        @endif

        @if ($errors->any())
            <div class="alert alert-warning">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
            </div>
        @endif

        <div class="card-body">
            <a href="{{ route('customers.create') }}">
                <button id="table2-new-row-button" class="btn btn-primary mb-4">{{ __('Crear Cliente') }}</button>
            </a>

            <form method="get">
                <div class="row mb-2">
                    <div class="col-4 inline">
                        <input type="text" name="search" value="{{$search ?? ''}}" placeholder="Nombre Cliente" class="form-control">
                    </div>
                    <div class="col-1">
                        <button class="btn btn-info">Buscar</button>
                    </div>
                </div>
            </form>

            <div class="table-responsive border">
                <table class="table table-hover mb-0 text-md-nowrap">
                    <thead class="thead">
                        <tr>
                            <th>No</th>

										<th>Nombre</th>
										<th>Ruc</th>
										<th>Registro</th>
										<th>Giro</th>
										<th>Email</th>
										<th>Teléfonos</th>
										<th>Contacto</th>
										<th>Coordenadas</th>

                            <th></th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($customers as $customer)
                            <tr>
                                <td>{{ ++$i }}</td>

											<td>{{ $customer->name }}</td>
											<td>{{ $customer->nit }}</td>
											<td>{{ $customer->register }}</td>
											<td>{{ $customer->order }}</td>
											<td>{{ $customer->email }}</td>
											<td>{{ $customer->phones }}</td>
											<td>
                                                <ul>
                                                    <li>NOMBRE: {{ $customer->contact_name }}</li>
                                                    <li>TELÉFONO: {{ $customer->contact_phone }}</li>
                                                    <li>MÓVIL: {{ $customer->mobile_phone }}</li>
                                                    <li>EMAIL: {{ $customer->contact_email }}</li>
                                                </ul>
                                            </td>
											<td>
                                                @php
                                                    if(is_string($customer->coordinates) && !empty($customer->coordinates)){
                                                        $customer->coordinates = json_decode($customer->coordinates, true);
                                                    }
                                                @endphp
                                                @if(isset($customer->coordinates['latitude']) && isset($customer->coordinates['longitude']))

                                                        @map([
                                                            'lat' => $customer->coordinates['latitude'],
                                                            'lng' => $customer->coordinates['longitude'],
                                                            'zoom' =>15 ,
                                                            'markers' => [
                                                                [
                                                                    'title' => 'Cliente',
                                                                    'lat' => $customer->coordinates['latitude'],
                                                                    'lng' => $customer->coordinates['longitude'],
                                                                ],
                                                            ],
                                                        ])
                                                @endif
                                            </td>

                                <td>
                                    <form action="{{ route('customers.destroy',$customer->id) }}" method="POST" onsubmit="return confirm('¿Realmente desea eliminar el cliente?')">
                                        <a class="btn btn-sm btn-success" href="{{ route('customers.edit',$customer->id) }}">
                                            <i class="fa fa-fw fa-edit"></i>
                                        </a>
                                        @csrf
                                        @method('DELETE')
                                        <button type="submit" class="btn btn-danger btn-sm">
                                            <i class="fa fa-fw fa-trash"></i>
                                        </button>
                                    </form>


                                    <a class="btn btn-sm btn-info m-1" href="{{ route('branch-offices.index',$customer->id) }}" title="Sucursales">
                                        <i class="fa fa-fw fa-building"></i>
                                    </a>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
                {!! $customers->appends(['search' => $search])->links('pagination::bootstrap-5') !!}
            </div>
        </div>
    </div>


@endsection

@section('page-scripts')
    @mapscripts
@endsection
