@extends('layouts.main')

@section('title', '| Pedidos')
@section('titlePage', 'Ordenes de retiro')

@section('content')
    <div class="card">
        <div class="card-header pb-0">
            <div class="d-flex justify-content-between">
                <h2 class="card-title mg-b-0">{{ __('Listado de Ordenes de retiro') }}</h2>
            </div>
        </div>
        @if ($message = Session::get('success'))
            <div class="alert alert-success">
                <p>{{ $message }}</p>
            </div>
        @endif

        <div class="card-body">
            @role('Taller') 
            @else
                <a href="{{ route('orders.create') }}">
                    <button id="table2-new-row-button" class="btn btn-primary mb-4">{{ __('Crear Orden de retiro') }}</button>
                </a>
                @endrole

            <div class="table-responsive border">
            <form id="bulk-update-form" method="POST" action="{{ route('orders.updateBulk') }}">
    @csrf
    @method('PUT')
    <table class="table table-hover mb-0 text-md-nowrap">
        <thead>
            <tr>
                <th>
                    <input type="checkbox" id="select-all"> <!-- Checkbox para seleccionar todas las órdenes -->
                </th>
                <th>Orden de retiro</th>
                <th>Cantidad</th>
                <th>Fecha Orden de retiro</th>
                <th>Cliente</th>
                <th>Estado</th>
                <th>Cantidad</th>
                <th>Prioridad</th>
                
            </tr>
        </thead>
        <tbody>
            @foreach ($orders as $order)
                <tr>
                    <td>
                        <input type="checkbox" name="order_ids[]" value="{{ $order->id }}" class="order-checkbox">
                    </td>
                    <td>{{ $order->id }}</td>
                    <td>{{ count($order->orderDetails ?? []) }}</td>
                    <td>{{ $order->created_at_format }}</td>
                    <td>{{ $order?->customer?->name }}</td>
                    <td>{{ \App\Models\Order::$states[$order->state] }}</td>
                    <td>{{ count($order->orderDetails ?? []) }}</td>
                    <td>
                        @role('Taller')
                        @if($order->priority === 0)
                            <p class="text-success">Normal</p>
                        @else
                            <p class="text-danger">Alta</p>
                        @endif
                        @else
                        @if($order->priority === 0)
                            <a href="#" data-bs-toggle="modal" data-bs-target="#modalCustomer{{$order->id}}">
                                <p class="text-success">Normal</p>
                            </a>
                        @else
                            <a href="#" data-bs-toggle="modal" data-bs-target="#modalCustomer{{$order->id}}">
                                <p class="text-danger">Alta</p>
                            </a>
                        @endif
                        @endrole    

                        <div class="modal fade" id="modalCustomer{{$order->id}}">
                            <div class="modal-dialog modal-dialog-centered text-center" role="document">
                                <div class="modal-content modal-content-demo">
                                    <div class="modal-header">
                                        <h6 class="modal-title">Cambiar Prioridad</h6>
                                        <button aria-label="Close" class="btn-close" data-bs-dismiss="modal"></button>
                                    </div>
                                    <div class="modal-body text-start">
                                        <div class="row">
                                            <form method="POST" action="{{ route('orders.updatePriority', $order->id) }}" role="form">
                                                @csrf
                                                @method('PUT')
                                                <div class="col-6">
                                                    <label>Prioridad</label>
                                                    <select name="priority" class="form-control">
                                                        <option value="0">Normal</option>
                                                        <option value="1">Alta</option>
                                                    </select>
                                                </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="submit" class="btn btn-success">Guardar</button>
                                            <button type="button" class="btn btn-light" data-bs-dismiss="modal">Cerrar</button>
                                        </div>
                                            </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </td>
                    <td>
                        <form action="{{ route('orders.destroy',$order->id) }}" method="POST" onsubmit="return confirm('Realmente desea eliminar la orden de retiro?')">
                            @if($order->state == 'NEW')
                                <a class="btn btn-sm btn-info" href="{{ route('orders.workshop',$order->id) }}">Validar a 09rea Tcnica</a>

                                @if(file_exists(storage_path('app/orders/' . $order->id . '.pdf')))
                                    <a class="btn btn-sm btn-success" href="{{ route('orders.customerEmail',$order->id) }}">Enviar documento Cliente</a>
                                @else
                                    <a class="btn btn-sm btn-info" href="{{ route('orders.customerEmail',$order->id) }}">Enviar documento Cliente</a>
                                @endif
                            @elseif($order->state == 'TO_WORKSHOP')
                                @role('Taller')
                                    <a class="btn btn-sm btn-info" href="{{ route('orders.workshop.received',$order->id) }}">Recibir en 09rea Tcnica</a>
                                @endrole
                            @elseif($order->state != 'DRAFT' && $order->state != 'NEW' && $order->state != 'DONE')
                                <a class="btn btn-sm btn-info" href="#">Enviado</a>
                            @elseif($order->state == 'TO_BILLING')
                            <a class="btn btn-sm btn-info" href="#">Enviado para facturación</a>
                            @endif

                            <a class="btn btn-sm btn-success" href="{{ route('orders.edit',$order->id) }}"><i class="fa fa-fw fa-edit"></i></a>
                            @if($order->state == 'NEW')
                                @csrf
                                @method('DELETE')
                                <button type="submit" class="btn btn-danger btn-sm"><i class="fa fa-fw fa-trash"></i></button>
                            @endif
                        </form>
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
    <button type="submit" class="btn btn-primary mt-3">Actualizar a Facturacin</button>
</form>
                {!! $orders->links('pagination::bootstrap-5') !!}
            </div>
        </div>
    </div>
    <script>
    document.getElementById('select-all').addEventListener('click', function() {
        const checkboxes = document.querySelectorAll('.order-checkbox');
        checkboxes.forEach(checkbox => {
            checkbox.checked = this.checked;
        });
    });
</script>

@endsection
