<?php

use App\Http\Controllers\ActionController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\BranchOfficeController;
use App\Http\Controllers\BrandController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\ClassController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\ManagementController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\PDFController;
use App\Http\Controllers\PrestamosController;
use App\Http\Controllers\PrestamosOrderController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\RefillController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\TypeManagementController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    return redirect()->route('login',['__cx' => time()]);
});

Auth::routes(['register' => false]);


Route::group(['middleware' => ['auth']], function (){
    Route::get('/logout', [LoginController::class, 'logout'])->name('logout.get');
    Route::get('/profile', [LoginController::class, 'profile'])->name('profile');
    Route::get('/dashboard', [HomeController::class, 'index'])->name('dashboard');
    Route::get('/dashboardbp', [HomeController::class, 'byPriority'])->name('dashboardbp');

    Route::post('/assign', [HomeController::class, 'assign'])->name('assign');

    Route::resource('customers', CustomerController::class);

    Route::resource('customers/{customer}/branch-offices', BranchOfficeController::class);
    Route::get('load-branchs/{customer?}', [BranchOfficeController::class, 'loadBranchs'])->name('branchs.load');
    Route::get('load-branch/{branchOffice}', [BranchOfficeController::class, 'loadBranchOffice'])->name('branch.load');

    Route::resource('brands', BrandController::class);
    Route::resource('categories', CategoryController::class);

    Route::resource('products', ProductController::class);
    Route::get('products-search', [ProductController::class, 'search'])->name('products.search');
    Route::get('products-add', [ProductController::class, 'addProduct'])->name('products.add');

    Route::resource('refills', RefillController::class);
    Route::resource('users', UserController::class);
    Route::resource('orders', OrderController::class);


    Route::resource('classes', ClassController::class)->except('update');
    Route::put('orderUpdatePriority/{id}', [OrderController::class, 'updatePriority'])->name('orders.updatePriority');
    Route::put('orderUpdatePriority-oper/{id}', [OrderController::class, 'updatePriorityOper'])->name('orders.updatePriority-oper');
    Route::put('update-bulk', [OrderController::class, 'updateBulk'])->name('orders.updateBulk');

    Route::put('/order-details/{id}/extras', [OrderController::class, 'updateExtras'])->name('order-details.updateExtras');
    Route::patch('classes/{classe}', [ClassController::class, 'update'])->name('classes.update');
    Route::get('alert', [HomeController::class, 'alert'])->name('alert.index');
    Route::get('alert/{usage}/{state}', [HomeController::class, 'alertApproved'])->name('alert.aprroved');
    Route::get('alert-prestamo/{prestamo}/{state}', [HomeController::class, 'alertPrestamoApproved'])->name('alert-prestamo.aprroved');

    Route::post('orders-photo/{order}/{orderDetail}', [OrderController::class, 'photoStore'])->name('orders.photo.store');

    Route::get('/photo/{order}/{s}', [OrderController::class, 'photo'])->name('photo');
    Route::get('/workshop/{order}', [OrderController::class, 'toWorkshop'])->name('orders.workshop');
    Route::get('/workshop-received/{order}', [OrderController::class, 'workshop'])->name('orders.workshop.received');
    Route::put('/workshop-doing/{order}', [OrderController::class, 'doing'])->name('orders.doing');
    Route::get('/forbilling', [OrderController::class, 'forBilling'])->name('orders.forbilling');
    Route::get('/email-customer/{order}', [OrderController::class, 'customerEmail'])->name('orders.customerEmail');
    Route::get('/invoiced/{order}', [OrderController::class, 'invoiced'])->name('orders.invoiced');
    Route::get('/tecnical/{orderDetail}', [OrderController::class, 'tecnical'])->name('orders.tecnical');
     

    Route::get('/refills-search', [RefillController::class, 'search'])->name('refills.search');
    Route::get('/refills-download/{refill}', [RefillController::class, 'download'])->name('refills.download');
    Route::post('/refills-assign', [RefillController::class, 'assign'])->name('refills-save-tech');
    Route::post('/refills-assign-all', [RefillController::class, 'assignAll'])->name('refills-save-tech-all');
    Route::get('/tecnical-done', [RefillController::class, 'done'])->name('tecnical.done');
    Route::get('/tecnical-done-order/{order}', [RefillController::class, 'doneOrder'])->name('tecnical.done.order');

    Route::get('qrcode/{orderDetail}', [OrderController::class, 'qrcode'])->name('qrcode');

    Route::get('report', [HomeController::class, 'report'])->name('report.index');
    Route::get('report-excel', [HomeController::class, 'reportExcel'])->name('report.index.excel');

    Route::get('report-pending', [HomeController::class, 'reportPending'])->name('report.pending');
    Route::get('report-pending-excel', [HomeController::class, 'reportPendingExcel'])->name('report.pending.excel');

    Route::get('report-technical', [HomeController::class, 'reportTechnical'])->name('report.technical');
    Route::get('report-technical-excel', [HomeController::class, 'reportTechnicalExcel'])->name('report.technical.excel');

    Route::get('report-recharge', [HomeController::class, 'reportRecharge'])->name('report.recharge');
    Route::get('report-recharge-excel', [HomeController::class, 'reportRechargeExcel'])->name('report.recharge.excel');

    Route::get('report-orders-workshop', [ReportController::class, 'workshop'])->name('report.workshop');
    Route::get('report-orders-workshop-excel', [ReportController::class, 'workshopExcel'])->name('report.workshop.excel');

    Route::get('report-t/{test}', [ReportController::class, 'test'])->name('report.test');

    Route::get('report-orders-prestamos', [ReportController::class, 'prestamos'])->name('report.prestamos');
    Route::get('report-orders-prestamos-excel', [ReportController::class, 'prestamosExcel'])->name('report.prestamos.excel');

    Route::post('generate-print-cards', [HomeController::class, 'generatePrintCards'])->name('report.generatePrintCards');
    Route::get('download-print-cards', [HomeController::class, 'downloadPrintCards'])->name('report.downloadPrintCard');
    Route::get('download-external/{orderDetail}', [HomeController::class, 'downloadExternal'])->name('download.external');
    Route::get('download-prestamo/{prestamo}', [HomeController::class, 'downloadPrestamo'])->name('download.prestamo');

    //modulo prestamos 
    Route::resource('prestamos', PrestamosController::class);
    
    Route::get('prestamos-add', [PrestamosController::class, 'create'])->name('prestamo.create');
    Route::get('stock-add', [PrestamosController::class, 'createstock'])->name('stock.create');
    Route::get('stock/{id}/edit', [PrestamosController::class, 'editstock'])->name('stock.edit');
    Route::put('stock/update/{id}', [PrestamosController::class, 'updatestock'])->name('stock.update');
    Route::post('stock/store', [PrestamosController::class, 'storestock'])->name('stock.store');
    Route::put('prestamodevolucion/{id}', [PrestamosController::class, 'devolucion'])->name('prestamo.devolucion');

    Route::resource('prestamos-orders', PrestamosOrderController::class);
    Route::get('products-orders-search', [PrestamosOrderController::class, 'searchStock'])->name('productsOrder.search');
    Route::get('orders-search', [PrestamosOrderController::class, 'searchOrderPrestamo'])->name('prestamoOrder.search');
    Route::get('prestamo-detail-add', [PrestamosOrderController::class, 'addPrestamoDetail'])->name('prestamo-detail.add');
    Route::get('prestamo-detail-order-add', [PrestamosOrderController::class, 'addPrestamoDetailOrder'])->name('prestamo-detail-order.add');

    //autocomplete
    Route::get('/autocomplete/productos/{brand_id}', [ProductController::class, 'buscarProductosPorMarca']);
    Route::get('/autocomplete/clientes', [CustomerController::class, 'buscarClientes']);
    Route::get('/autocomplete/marcas', [BrandController::class, 'buscarMarcas']);

    Route::resource('provider', ActionController::class);

    Route::get('parcial/{orderDetail}/{check}', [HomeController::class, 'parcial'])->name('parcial');

    Route::get('/generar-pdf', [PDFController::class, 'generarPDF'])->name('vineta');

    Route::resource('type-managements', TypeManagementController::class);
    Route::resource('managements', ManagementController::class);
    Route::post('managements/store-dashboard', [ManagementController::class, 'storeDashboard'])->name('managements.store.dashboard');
});

